nisteag
=======

An implementation of recommendations from the NIST Electronic Authentication Guideline

.. image:: https://travis-ci.org/yougov/nisteag.svg?branch=master
   :target: https://travis-ci.org/yougov/nisteag
   :alt: Build Status

.. image:: https://codeclimate.com/github/yougov/nisteag/badges/coverage.svg
   :target: https://codeclimate.com/github/yougov/nisteag/coverage
   :alt: Test Coverage

.. image:: https://codeclimate.com/github/yougov/nisteag/badges/gpa.svg
   :target: https://codeclimate.com/github/yougov/nisteag
   :alt: Code Climate

.. image:: https://codeclimate.com/github/yougov/nisteag/badges/issue_count.svg
   :target: https://codeclimate.com/github/yougov/nisteag
   :alt: Issue Count

The starting implementation will be for Special Publication 800-63-2: http://dx.doi.org/10.6028/NIST.SP.800-63-2

The full documentation is here: http://nisteag.readthedocs.io/
